'''
ASL constant definitions

THIS FILE IS GENERATED, DON'T UPDATE MANUALLY
'''

ASL_LEVEL_EMERG = 0
ASL_LEVEL_ALERT = 1
ASL_LEVEL_CRIT = 2
ASL_LEVEL_ERR = 3
ASL_LEVEL_WARNING = 4
ASL_LEVEL_NOTICE = 5
ASL_LEVEL_INFO = 6
ASL_LEVEL_DEBUG = 7
ASL_STRING_EMERG = 'Emergency'
ASL_STRING_ALERT = 'Alert'
ASL_STRING_CRIT = 'Critical'
ASL_STRING_ERR = 'Error'
ASL_STRING_WARNING = 'Warning'
ASL_STRING_NOTICE = 'Notice'
ASL_STRING_INFO = 'Info'
ASL_STRING_DEBUG = 'Debug'
ASL_QUERY_OP_CASEFOLD = 16
ASL_QUERY_OP_PREFIX = 32
ASL_QUERY_OP_SUFFIX = 64
ASL_QUERY_OP_SUBSTRING = 96
ASL_QUERY_OP_NUMERIC = 128
ASL_QUERY_OP_REGEX = 256
ASL_QUERY_OP_EQUAL = 1
ASL_QUERY_OP_GREATER = 2
ASL_QUERY_OP_GREATER_EQUAL = 3
ASL_QUERY_OP_LESS = 4
ASL_QUERY_OP_LESS_EQUAL = 5
ASL_QUERY_OP_NOT_EQUAL = 6
ASL_QUERY_OP_TRUE = 7
ASL_KEY_TIME = 'Time'
ASL_KEY_TIME_NSEC = 'TimeNanoSec'
ASL_KEY_HOST = 'Host'
ASL_KEY_SENDER = 'Sender'
ASL_KEY_FACILITY = 'Facility'
ASL_KEY_PID = 'PID'
ASL_KEY_UID = 'UID'
ASL_KEY_GID = 'GID'
ASL_KEY_LEVEL = 'Level'
ASL_KEY_MSG = 'Message'
ASL_KEY_READ_UID = 'ReadUID'
ASL_KEY_READ_GID = 'ReadGID'
ASL_KEY_EXPIRE_TIME = 'ASLExpireTime'
ASL_KEY_MSG_ID = 'ASLMessageID'
ASL_KEY_SESSION = 'Session'
ASL_KEY_REF_PID = 'RefPID'
ASL_KEY_REF_PROC = 'RefProc'
ASL_KEY_AUX_TITLE = 'ASLAuxTitle'
ASL_KEY_AUX_UTI = 'ASLAuxUTI'
ASL_KEY_AUX_URL = 'ASLAuxURL'
ASL_KEY_AUX_DATA = 'ASLAuxData'
ASL_KEY_OPTION = 'ASLOption'
ASL_KEY_SENDER_INSTANCE = 'SenderInstance'
ASL_TYPE_MSG = 0
ASL_TYPE_QUERY = 1
ASL_FILTER_MASK_EMERG = 1
ASL_FILTER_MASK_ALERT = 2
ASL_FILTER_MASK_CRIT = 4
ASL_FILTER_MASK_ERR = 8
ASL_FILTER_MASK_WARNING = 16
ASL_FILTER_MASK_NOTICE = 32
ASL_FILTER_MASK_INFO = 64
ASL_FILTER_MASK_DEBUG = 128
ASL_OPT_STDERR = 1
ASL_OPT_NO_DELAY = 2
ASL_OPT_NO_REMOTE = 4
ASL_LOG_DESCRIPTOR_READ = 1
ASL_LOG_DESCRIPTOR_WRITE = 2
